Changelog
=========

0.9.3 (2015-08-27)
------------------

- Add Django 1.7 compatibility. [Alex Bliskovsky]


0.9.2 (2015-07-16)
------------------

- Fix ``setup.py`` dependencies. [Alex Bliskovsky]
- Fix tests. [Alex Bliskovsky]
- Fix compatibility with django's cached loader. [Alex Bliskovsky]
- Fix context processing. [Alex Bliskovsky]


0.9.1 (2015-06-22)
------------------

- Fix 'From' field always being default


0.9.0 (2015-06-18)
------------------

- Initial version
